@@ -2,7 +2,7 @@ package Resource::Silo::Container;
 
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -84,7 +84,7 @@ sub _instantiate_resource {
     croak "Illegal resource name '$name'"
         unless $name =~ $ID_REX;
 
-    my $spec = $self->{-spec}->spec($name);
+    my $spec = $self->{-spec}{$name};
     $arg //= '';
 
     croak "Attempting to fetch nonexistent resource '$name'"
@@ -375,6 +375,16 @@ sub fresh {
     return ${+shift}->_instantiate_resource(@_);
 };
 
+=head2 meta
+
+Get resource metadata object (a L<Resource::Silo::Metadata>).
+
+=cut
+
+sub meta {
+    return ${+shift}->{-spec};
+};
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2023, Konstantin Uvarin, C<< <khedin@gmail.com> >>
