@@ -2,7 +2,7 @@ package Resource::Silo::Metadata;
 
 use strict;
 use warnings;
-our $VERSION = '0.1200_01';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -20,13 +20,11 @@ See also L<Resource::Silo/meta>.
 =cut
 
 use Carp;
-use Module::Load qw( load );
 use Scalar::Util qw( looks_like_number reftype );
 use Sub::Quote qw( quote_sub );
 
 my $BARE_REX = '[a-z][a-z_0-9]*';
-my $ID_REX   = qr(^$BARE_REX$)i;
-my $MOD_REX  = qr(^$BARE_REX(?:::$BARE_REX)*$)i;
+my $ID_REX   = qr(^$BARE_REX$);
 
 # Define possible reftypes portably
 my $CODE   = reftype sub { };
@@ -42,8 +40,8 @@ $target is the name of the module where resource access methods will be created.
 sub new {
     my ($class, $target) = @_;
     return bless {
-        target  => $target,
-        preload => [],
+        -target  => $target,
+        -preload => [],
     }, $class;
 };
 
@@ -57,16 +55,13 @@ my %known_args = (
     argument        => 1,
     class           => 1,
     dependencies    => 1,
-    derived         => 1,
+    derivative      => 1,
     cleanup         => 1,
     cleanup_order   => 1,
     fork_cleanup    => 1,
     ignore_cache    => 1,
     init            => 1,
-    literal         => 1,
-    loose_deps      => 1,
     preload         => 1,
-    require         => 1,
 );
 sub add {
     my $self = shift;
@@ -76,12 +71,12 @@ sub add {
         unshift @_, init => $init;
     }
     my (%spec) = @_;
-    my $target = $self->{target};
+    my $target = $self->{-target};
 
     croak "resource: name must be an identifier"
         unless defined $name and !ref $name and $name =~ $ID_REX;
     croak "resource: attempt to redefine resource '$name'"
-        if defined $self->{resource}{$name};
+        if defined $self->{$name};
     croak "resource: attempt to replace existing method '$name' in $target"
         if $target->can($name);
 
@@ -89,29 +84,6 @@ sub add {
     croak "resource '$name': unknown arguments in specification: @extra"
         if @extra;
 
-    {
-        # validate 'require' before 'class'
-        if (!ref $spec{require}) {
-            $spec{require} = defined $spec{require} ? [ $spec{require} ] : [];
-        };
-        croak "resource '$name': 'require' must be a module name or a list thereof"
-            unless ref $spec{require} eq 'ARRAY';
-        my @bad = grep { $_ !~ $MOD_REX } @{ $spec{require} };
-        croak "resource '$name': 'require' doesn't look like module name(s): "
-            .join ", ", map { "'$_'" } @bad
-                if @bad;
-    };
-
-    if (defined (my $value = $spec{literal})) {
-        defined $spec{$_}
-            and croak "resource '$name': 'literal' is incompatible with '$_'"
-                for qw( init class argument );
-        $spec{init}            = sub { $value };
-        $spec{dependencies}  //= [];
-        $spec{derived}       //= 1;
-        $spec{cleanup_order} //= 9 ** 9 ** 9;
-    };
-
     _make_init_class($self, $name, \%spec)
         if (defined $spec{class});
 
@@ -125,33 +97,13 @@ sub add {
         $spec{allowdeps} = { map { $_ => 1 } @$deps };
     };
 
-    unless ($spec{loose_deps}) {
-        # resources with argument should be allowed to depend on themselves
-        local $self->{resource}{$name} = {}
-            if defined $spec{argument};
-
-        if ($spec{allowdeps}) {
-            my @fwd = grep { !$self->{resource}{$_} } keys %{ $spec{allowdeps} };
-            croak "resource '$name': forward dependencies require 'loose_deps' flag: "
-                .join( ", ", map { "'$_'" } @fwd)
-                    if @fwd;
-        } else {
-            $spec{autodeps}  = 1;
-            $spec{allowdeps} = {
-                map { $_ => 1 } keys %{ $self->{resource} },
-            };
-        };
-    };
-
     croak "resource '$name': 'init' must be a function"
         unless ref $spec{init} and reftype $spec{init} eq $CODE;
 
     if (!defined $spec{argument}) {
-        $spec{orig_argument} = '';
         $spec{argument} = \&_is_empty;
     } elsif (ref $spec{argument} eq $REGEXP) {
         my $rex = qr(^(?:$spec{argument})$);
-        $spec{orig_argument} = $spec{argument};
         $spec{argument} = sub { $_[0] =~ $rex };
     } elsif ((reftype $spec{argument} // '') eq $CODE) {
         # do nothing, we're fine
@@ -176,19 +128,17 @@ sub add {
         if defined $spec{fork_cleanup} and (reftype $spec{fork_cleanup} // '') ne $CODE;
 
     if ($spec{preload}) {
-        push @{ $self->{preload} }, $name;
+        push @{ $self->{-preload} }, $name;
     };
 
-    $spec{origin} = Carp::shortmess("declared");
-    $spec{origin} =~ s/\D+$//s;
-    $self->{resource}{$name} = \%spec;
+    $self->{$name} = \%spec;
 
     # Move code generation into Resource::Silo::Container
     # so that exceptions via croak() are attributed correctly.
     {
         no strict 'refs'; ## no critic Strictures
         *{"${target}::$name"} =
-            Resource::Silo::Container::_silo_make_accessor($name, \%spec);
+            Resource::Silo::Container::_make_resource_accessor($name, \%spec);
     }
 
     return $self;
@@ -201,7 +151,7 @@ sub _make_init_class {
     $spec->{dependencies} //= {};
 
     croak "resource '$name': 'class' doesn't look like a package name: '$class'"
-        unless $class =~ $MOD_REX;
+        unless $class =~ /^$BARE_REX(?:::$BARE_REX)*$/i;
     defined $spec->{$_} and croak "resource '$name': 'class' is incompatible with '$_'"
         for qw(init argument);
     croak "resource '$name': 'class' requires 'dependencies' to be a hash"
@@ -209,11 +159,9 @@ sub _make_init_class {
 
     my %deps = %{ $spec->{dependencies} };
 
-    push @{ $spec->{require} }, $class;
-
     my %pass_args;
     my @realdeps;
-    my @body = ("my \$c = shift;", "$class->new(" );
+    my @body = ("my \$c = shift;", "require $class;", "$class->new(" );
 
     # format: constructor_arg => [ resource_name, resource_arg ]
     foreach my $key (keys %deps) {
@@ -253,7 +201,7 @@ sub _make_init_class {
         (%pass_args ? { '%pass_args' => \%pass_args, } : {}),
         {
             no_install => 1,
-            package    => $self->{target},
+            package    => $self->{-target},
         }
     );
     $spec->{dependencies} = \@realdeps;
@@ -269,86 +217,16 @@ sub _make_dsl {
 Returns a list (or arrayref in scalar context)
 containing the names of known resources.
 
-The order is not guaranteed.
-
 B<EXPERIMENTAL>. Return value structure is subject to change.
 
 =cut
 
 sub list {
     my $self = shift;
-    my @list = sort keys %{ $self->{resource} };
+    my @list = sort grep { !/^-/ } keys %$self;
     return wantarray ? @list : \@list;
 };
 
-=head2 show( $name )
-
-Returns a shallow copy of resource specification.
-
-B<EXPERIMENTAL>. Return value structure is subject to change.
-
-=cut
-
-sub show {
-    my ($self, $name) = @_;
-
-    my $all = $self->{resource};
-    my $spec = $all->{$name};
-    croak "Unknown resource '$name'"
-        unless $spec;
-
-    my %show = %$spec; # shallow copy
-
-    if (my $deps = delete $show{allowdeps}) {
-        $show{dependencies} = [ keys %$deps ];
-    };
-
-    if (exists $show{orig_argument}) {
-        $show{argument} = delete $show{orig_argument};
-    };
-
-    return \%show;
-};
-
-=head2 self_check()
-
-Check setup validity. Dies on errors, return C<$self> otherwise.
-
-The following checks are available so far:
-
-=over
-
-=item * dependencies must be defined;
-
-=item * required modules must be loadable.
-
-=back
-
-B<EXPERIMENTAL>. Interface & performed checks may change in the future.
-
-=cut
-
-sub self_check {
-    my $self = shift;
-
-    my $res = $self->{resource};
-    foreach my $name (sort keys %$res) {
-        my $entry = $res->{$name};
-
-        my @missing_deps = grep { !$res->{$_} } keys %{ $entry->{allowdeps} || {} };
-        croak "resource '$name': missing dependencies: ".
-            join ", ", map { "'$_'" } @missing_deps
-                if @missing_deps;
-
-        foreach my $mod ( @{ $entry->{require} } ) {
-            eval { load $mod; 1 }
-                or croak "resource '$name': failed to load '$mod': $@";
-        };
-    };
-
-    return $self;
-};
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2023, Konstantin Uvarin, C<< <khedin@gmail.com> >>
